@@ -14,6 +14,7 @@
 
 
 import contextlib
+import hashlib
 import html
 import json
 import logging
@@ -22,7 +23,6 @@ import re
 import os
 import sys
 import time
-import tempfile
 import urllib.error
 import urllib.parse
 import urllib.request
@@ -61,6 +61,8 @@ except AttributeError:
 
 ALBUM_ART_SIZE = 96
 TEXT_X_PADDING = 12
+# 15 days in seconds to retain album art files.
+ART_CACHE_TIME = 1.296e+6
 
 FALLBACK_BLACK = Gdk.RGBA(red=0.0, green=0.0, blue=0.0, alpha=1.0)
 FALLBACK_WHITE = Gdk.RGBA(red=1.0, green=1.0, blue=1.0, alpha=1.0)
@@ -298,7 +300,7 @@ class PithosWindow(Gtk.ApplicationWindow):
         self._query_position = Gst.Query.new_position(Gst.Format.TIME)
         self._query_buffer = Gst.Query.new_buffering(Gst.Format.PERCENT)
 
-        self.player = Gst.ElementFactory.make("playbin", "player")
+        self.player = Gst.ElementFactory.make("playbin3", "player")
         self.player.set_property('buffer-duration', 3 * Gst.SECOND)
         self.rgvolume = Gst.ElementFactory.make("rgvolume", "rgvolume")
         self.rgvolume.set_property("album-mode", False)
@@ -369,8 +371,9 @@ class PithosWindow(Gtk.ApplicationWindow):
             if is_flatpak():
                 # However in flatpak that path is not readable by the host.
                 tempdir_base = os.path.join(GLib.get_user_cache_dir(), 'tmp')
-            self.tempdir = tempfile.TemporaryDirectory(prefix='pithos-', dir=tempdir_base)
-            logging.info("Created temporary directory {}".format(self.tempdir.name))
+            self.tempdir = os.path.join(tempdir_base, 'pithos_cache')
+            os.makedirs(self.tempdir, exist_ok=True)
+            logging.info("Created temporary directory {}".format(self.tempdir))
         except IOError as e:
             self.tempdir = None
             logging.warning('Failed to create a temporary directory: {}'.format(e))
@@ -848,6 +851,15 @@ class PithosWindow(Gtk.ApplicationWindow):
         else:
             self.user_play()
 
+    def clear_art_cache(self):
+        logging.info('Checking for expired art in cache')
+        timestamp = time.time()
+        with os.scandir(self.tempdir) as art_list:
+            for art in art_list:
+                age = timestamp - art.stat().st_mtime
+                if age > ART_CACHE_TIME:
+                    os.remove(os.path.join(self.tempdir, art.path))
+
     def get_playlist(self, start = False):
         if self.playlist_update_timer_id:
             GLib.source_remove(self.playlist_update_timer_id)
@@ -877,11 +889,16 @@ class PithosWindow(Gtk.ApplicationWindow):
                 return (None, None,) + extra
 
             file_url = None
+            song, index = extra
             if tmpdir:
                 try:
-                    with tempfile.NamedTemporaryFile(prefix='art-', suffix='.jpeg', dir=tmpdir.name, delete=False) as f:
-                        f.write(image)
-                        file_url = urllib.parse.urljoin('file://', urllib.parse.quote(f.name))
+                    self.clear_art_cache()
+                    filename_hash = hashlib.sha256((song.artist+song.album).encode('utf-8')).hexdigest()+'.jpeg'
+                    cache_file_path = os.path.join(self.tempdir, filename_hash)
+                    file_url = urllib.parse.urljoin('file://', urllib.parse.quote(cache_file_path))
+                    if not os.path.exists(cache_file_path):
+                        with open(cache_file_path, 'xb') as f:
+                            f.write(image)
                 except IOError:
                     logging.warning("Failed to write art tempfile")
 
