@@ -212,7 +212,7 @@ class PithosMprisService(DBusServiceObject):
         ]
 
         if window.stations_dlg:
-            # If stations_dlg exsists already
+            # If stations_dlg exists already
             # we missed the ready signal and
             # we should connect our handlers.
             self._stations_dlg_ready_handler()
@@ -495,14 +495,14 @@ class PithosMprisService(DBusServiceObject):
         return 'io.github.Pithos'
 
     @dbus_property(MEDIA_PLAYER2_IFACE, signature='as')
-    def SupportedUriScheme(self):
+    def SupportedUriSchemes(self):
         '''as Read only Interface MediaPlayer2'''
-        return ['', ]
+        return []
 
     @dbus_property(MEDIA_PLAYER2_IFACE, signature='as')
     def SupportedMimeTypes(self):
         '''as Read only Interface MediaPlayer2'''
-        return ['', ]
+        return []
 
     @dbus_property(MEDIA_PLAYER2_PLAYER_IFACE, signature='s')
     def PlaybackStatus(self):
